;*******************************************************************
;                           dsub.inc
;             Subtract 16 bit unsigned integers macro.
;*******************************************************************
;
;   The 16 bit result is stored in D0.
;   Performance :   ROM     :   locations
;                   RAM     :   
;                   cycles  :   max 10+13
;
;  Syntax: DFDFSub _D1, _D2        : Sub two 16 bit reg
;          DFDLSub _D1, _LH, _LL   : Sub 16 bit const from reg
;          DFSLSub _D1, _LL        : Sub  8 bit const from reg
;          D0DFSub _D2             : Sub 16 bit reg from D0
;          D0DLSub _LH, _LL        : Sub 16 bit const from D0
;          D0SLSub _LL             : Sub  8 bit const from D0
;*******************************************************************
;

IFNDEF    __REGISTERS
#include  "registrs.inc"
ENDIF
          EXTERN   dsub

DFDFSub   macro     _D1,      _D2
          movf      _D1,      W
          movwf     D0
          movf      _D1+1,    W
          movwf     D0+1
          movf      _D2,      W
          movwf     D1
          movf      _D2+1,    W
          movwf     D1+1
          call      dsub
          endm

DFD1Sub   macro     _D1
          movf      _D1,      W
          movwf     D0
          movf      _D1+1,    W
          movwf     D0+1
          call      dsub
          endm

DFDLSub   macro     _D1,      _LH,      _LL
          movf      _D1,      W
          movwf     D0
          movf      _D1+1,    W
          movwf     D0+1
          movlw     _LH
          movwf     D1
          movlw     _LL
          movwf     D1+1
          call      dsub
          endm

DFSLSub   macro     _D1,      _LL
          movf      _D1,      W
          movwf     D0
          movf      _D1+1,    W
          movwf     D0+1
          clrf      D1
          movlw     _LL
          movwf     D1+1
          call      dsub
          endm

D0DFSub   macro     _D2
          movf      _D2,      W
          movwf     D1
          movf      _D2+1,    W
          movwf     D1+1
          call      dsub
          endm

D0DLSub   macro     _LH,      _LL
          movlw     _LH
          movwf     D1
          movlw     _LL
          movwf     D1+1
          call      dsub
          endm

D0SLSub   macro     _LL
          clrf      D1
          movlw     _LL
          movwf     D1+1
          call      dsub
          endm

